easy_app_links library

Easy App Links Package

A powerful diagnostic tool to verify and handle Android/iOS deep links with zero-config console reporting.

Classes

Easy App Links - A powerful diagnostic tool for Flutter deep links

Typedefs

OnLinkReceived = void Function(Uri uri, Map<String, String> params)
Callback function type for when a deep link is received